import 'package:flutter/material.dart';
import 'package:jobportal/services/global_variables.dart';
import 'package:jobportal/UI/bottom_navigation_bar/jobseeker_bottom_navigation_bar.dart';
import 'package:jobportal/data/job.dart';
import 'package:jobportal/logic/fetch.dart';
import '../../widgets/jobwidget.dart';
import '../bottom_navigation_bar/company_bottom_navigation_bar.dart';

class AllJobsScreen extends StatefulWidget {
// Add the job to the list
  const AllJobsScreen({super.key});

  @override
  State<AllJobsScreen> createState() => _AllJobsScreenState();
}

class _AllJobsScreenState extends State<AllJobsScreen> {
  int x = 0;
  late int pageNumber;

  List<Job> jobs = [];

  @override
  void initState() {
    super.initState();
    pageNumber = 0;

    fetchAllJobs();
  }

  void fetchAllJobs() async {
    jobs = await Fetch.getAllJobsByPage(pageNumber);
    setState(() {});
  }

  void _incrementPage() {
    setState(() {
      pageNumber++;
      fetchAllJobs();
    });
  }

  void _decrementPage() {
    setState(() {
      if (pageNumber >= 1) {
        pageNumber--;
        fetchAllJobs();
      }
    });
  }

  @override
  Widget build(BuildContext context) {
    return SafeArea(
        child: Scaffold(
            bottomNavigationBar: identifier.iscompany == true
                ? MyBottomNavigationBar(
                    indexNum: 1,
                  )
                : JobseekerBottomNavigationBar(
                    indexNum: 0,
                  ),
            backgroundColor: Colors.grey.shade300,
            drawer: const Drawer(),
            appBar: AppBar(
              iconTheme: const IconThemeData(color: Colors.black),
              title: const Center(
                child: Text("jobportal"),
              ),
              // flexibleSpace: Container(
              //   decoration: const BoxDecoration(
              //       gradient: LinearGradient(
              //           colors: [Colors.cyan, Colors.greenAccent],
              //           begin: Alignment.centerLeft,
              //           end: Alignment.centerRight,
              //           stops: [0.2, 0.9])),
              // ),
              backgroundColor: Colors.orange,
            ),
            body: Stack(
              children: [
                ListView.builder(
                  itemCount: jobs.length,
                  itemBuilder: (context, index) {
                    return ShowJobWidget(job: jobs[index]);
                  },
                ),
                Positioned(
                  bottom: 16,
                  left: 0,
                  right: 0,
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.center,
                    children: [
                      IconButton(
                        onPressed: _decrementPage,
                        icon: const Icon(
                          Icons.arrow_left,
                          color: Colors.red,
                          size: 40,
                        ),
                      ),
                      Padding(
                        padding: const EdgeInsets.symmetric(horizontal: 16.0),
                        child: Text(
                          'Page ${pageNumber + 1} ',
                          style: const TextStyle(fontWeight: FontWeight.bold),
                        ),
                      ),
                      IconButton(
                        onPressed: _incrementPage,
                        icon: const Icon(
                          Icons.arrow_right,
                          color: Colors.green,
                          size: 40,
                        ),
                      ),
                    ],
                  ),
                )
              ],
            )));
  }
}
