import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import '../../services/global_methods.dart';
import '../../services/global_variables.dart';
import '../bottom_navigation_bar/company_bottom_navigation_bar.dart';

class CreateJobScreen extends StatefulWidget {
  const CreateJobScreen({super.key});

  @override
  State<CreateJobScreen> createState() => _CreateJobScreenState();
}

class _CreateJobScreenState extends State<CreateJobScreen> {
  final _globalKey = GlobalKey<FormState>();

  final TextEditingController _name = TextEditingController();
  final TextEditingController _status = TextEditingController();
  final TextEditingController _timeType = TextEditingController();
  final TextEditingController _description = TextEditingController();
  final TextEditingController _minSallary = TextEditingController();
  final TextEditingController _maxSallary = TextEditingController();
  final TextEditingController _specificationName = TextEditingController();
  final TextEditingController _requiredLevel = TextEditingController();
  final TextEditingController _experiance = TextEditingController();

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;

    return SafeArea(
      child: Scaffold(
        bottomNavigationBar: MyBottomNavigationBar(
          indexNum: 4,
        ),
        backgroundColor: Colors.grey.shade300,
        body: Container(
          // decoration: const BoxDecoration(
          //     gradient: LinearGradient(
          //         colors: [Colors.cyan, Colors.greenAccent],
          //         begin: Alignment.centerLeft,
          //         end: Alignment.centerRight,
          //         stops: [0.2, 0.9])),
          child: Center(
              child: Padding(
            padding: const EdgeInsets.all(7.0),
            child: Card(
              color: Colors.white10,
              child: SingleChildScrollView(
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    const SizedBox(
                      height: 10,
                    ),
                    const Align(
                      alignment: Alignment.center,
                      child: Padding(
                        padding: EdgeInsets.all(8.0),
                        child: Text(
                          "Upload New Job",
                          style: TextStyle(
                              color: Colors.black,
                              fontSize: 30,
                              fontWeight: FontWeight.bold,
                              fontStyle: FontStyle.italic),
                        ),
                      ),
                    ),
                    const SizedBox(
                      height: 10,
                    ),
                    const Divider(
                      thickness: 1,
                      color: Colors.grey,
                    ),
                    Padding(
                      padding: const EdgeInsets.all(0),
                      child: Form(
                        key: _globalKey,
                        child: Column(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          children: [
                            GlobalMethods.textTitle(label: 'Job name :'),
                            GlobalMethods.textFormFields(
                              valuekey: "Job Name",
                              controller: _name,
                              enabled: true,
                              fct: () {},
                              maxlength: 50,
                            ),
                            GlobalMethods.textTitle(label: 'Min salary :'),
                            GlobalMethods.textFormFields(
                              valuekey: "Min Salary",
                              controller: _minSallary,
                              enabled: true,
                              fct: () {},
                              maxlength: 50,
                            ),
                            GlobalMethods.textTitle(label: 'Max salary :'),
                            GlobalMethods.textFormFields(
                              valuekey: "Max Salary",
                              controller: _maxSallary,
                              enabled: true,
                              fct: () {},
                              maxlength: 50,
                            ),
                            GlobalMethods.textTitle(label: 'Time type :'),
                            GlobalMethods.textFormFields(
                              valuekey: "Time Type",
                              controller: _timeType,
                              enabled: false,
                              fct: () {
                                _selectTimeType(size: size);
                              },
                              maxlength: 50,
                            ),
                            GlobalMethods.textTitle(
                                label: 'Specification name :'),
                            GlobalMethods.textFormFields(
                              valuekey: "Specification Name",
                              controller: _specificationName,
                              enabled: true,
                              fct: () {
                                // _selectYourSpecification(size: size);
                              },
                              maxlength: 50,
                            ),
                            GlobalMethods.textTitle(label: 'ِAvailability :'),
                            GlobalMethods.textFormFields(
                              valuekey: "Status",
                              controller: _status,
                              enabled: false,
                              fct: () {
                                _selectStatus(size: size);
                              },
                              maxlength: 50,
                            ),
                            GlobalMethods.textTitle(label: 'Description :'),
                            GlobalMethods.textFormFields(
                              valuekey: "Description",
                              controller: _description,
                              enabled: true,
                              fct: () {},
                              maxlength: 250,
                            ),
                            GlobalMethods.textTitle(label: 'Experiance :'),
                            GlobalMethods.textFormFields(
                              valuekey: "Experiance",
                              controller: _experiance,
                              enabled: true,
                              fct: () {},
                              maxlength: 250,
                            ),
                            GlobalMethods.textTitle(label: 'Level :'),
                            GlobalMethods.textFormFields(
                              valuekey: "Level",
                              controller: _requiredLevel,
                              enabled: true,
                              fct: () {},
                              maxlength: 50,
                            ),
                            const SizedBox(height: 20),
                            InkWell(
                              onTap: () async {
                                if (_globalKey.currentState!.validate()) {
                                  await _submitForm();
                                }
                              },
                              child: Center(
                                  child: Container(
                                width: 200,
                                height: 50,
                                decoration: BoxDecoration(
                                    borderRadius: BorderRadius.circular(10),
                                    color: Colors.black),
                                child: const Center(
                                  child: Text(
                                    "Upload",
                                    style: TextStyle(
                                        fontWeight: FontWeight.bold,
                                        color: Colors.white,
                                        fontSize: 18),
                                  ),
                                ),
                              )),
                            ),
                            const SizedBox(height: 20),
                          ],
                        ),
                      ),
                    )
                  ],
                ),
              ),
            ),
          )),
        ),
      ),
    );
  }

  Future<void> _submitForm() async {
    try {
      final url = Uri.parse('$myUrl/api/jobs/add');

      final requestBody = {
        'id': "0",
        'name': _name.text,
        'timeType': _timeType.text,
        'description': _description.text,
        'minSalary': double.parse(_minSallary.text),
        'maxSalary': double.parse(_maxSallary.text),
        'status': bool.parse(_status.text),
        'specificationName': _specificationName.text,
        'companyId': identifier.id.toString(),
        'experience': _experiance.text,
        'requiredLevel': _requiredLevel.text,
      };

      ScaffoldMessenger.of(context).showSnackBar(
        const SnackBar(
          content: Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              Padding(
                padding: EdgeInsets.all(5.0),
                child: Text("Uploading..."),
              ),
              CircularProgressIndicator(),
            ],
          ),
          duration: Duration(minutes: 1),
        ),
      );

      final response = await http.post(
        url,
        headers: {
          'Content-Type': 'application/json',
          'Authorization': "Bearer ${identifier.token}",
        },
        body: jsonEncode(requestBody),
      );

      if (response.statusCode == 200) {
        _showSuccess();
      } else {
        _showFail();
      }
    } catch (error) {
      GlobalMethods.showErrorDialog(error: error.toString(), ctx: context);
    }
  }

  void _showSuccess() {
    ScaffoldMessenger.of(context).hideCurrentSnackBar();
    ScaffoldMessenger.of(context).showSnackBar(const SnackBar(
      content: Text('Your job uploaded successfully'),
      duration: Duration(seconds: 3),
    ));
  }

  void _showFail() {
    ScaffoldMessenger.of(context).hideCurrentSnackBar();
    ScaffoldMessenger.of(context).showSnackBar(const SnackBar(
      content: Text('There was an error occurred'),
      duration: Duration(seconds: 3),
    ));
  }

  void _selectTimeType({required Size size}) {
    showDialog(
        context: context,
        builder: (context) {
          return AlertDialog(
            backgroundColor: Colors.black54,
            title: const Text(
              "Select TimeType",
              textAlign: TextAlign.center,
              style: TextStyle(fontSize: 20, color: Colors.green),
            ),
            content: SizedBox(
              width: size.width * 0.9,
              child: ListView(
                shrinkWrap: true,
                children: [
                  Column(
                    mainAxisAlignment: MainAxisAlignment.start,
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      Padding(
                        padding: const EdgeInsets.all(10.0),
                        child: InkWell(
                          onTap: () {
                            setState(() {
                              _timeType.text = "Full-time and On-site Work";
                            });

                            Navigator.pop(context);
                          },
                          child: const Row(
                            mainAxisAlignment: MainAxisAlignment.start,
                            children: [
                              Icon(
                                Icons.arrow_right_alt_outlined,
                                color: Colors.white,
                              ),
                              SizedBox(
                                width: 6,
                              ),
                              Text(
                                "Part-time and On-site Work",
                                style: TextStyle(color: Colors.white),
                              )
                            ],
                          ),
                        ),
                      ),
                      const SizedBox(
                        height: 10,
                      ),
                      const Divider(
                        thickness: 1,
                        color: Colors.grey,
                      ),
                      Padding(
                        padding: const EdgeInsets.all(10.0),
                        child: InkWell(
                          onTap: () {
                            setState(() {
                              _timeType.text = "Part-time and Remotly Work";
                            });

                            Navigator.pop(context);
                          },
                          child: const Row(
                            mainAxisAlignment: MainAxisAlignment.start,
                            children: [
                              Icon(
                                Icons.arrow_right_alt_outlined,
                                color: Colors.white,
                              ),
                              SizedBox(
                                width: 6,
                              ),
                              Text(
                                "Part-time and Remotly Work",
                                style: TextStyle(color: Colors.white),
                              )
                            ],
                          ),
                        ),
                      ),
                      const SizedBox(
                        height: 10,
                      ),
                      const Divider(
                        thickness: 1,
                        color: Colors.grey,
                      ),
                      Padding(
                        padding: const EdgeInsets.all(10.0),
                        child: InkWell(
                          onTap: () {
                            setState(() {
                              _timeType.text = "Full-time and On-site Work";
                            });

                            Navigator.pop(context);
                          },
                          child: const Row(
                            mainAxisAlignment: MainAxisAlignment.start,
                            children: [
                              Icon(
                                Icons.arrow_right_alt_outlined,
                                color: Colors.white,
                              ),
                              SizedBox(
                                width: 6,
                              ),
                              Text(
                                "Full-time and On-site Work",
                                style: TextStyle(color: Colors.white),
                              )
                            ],
                          ),
                        ),
                      ),
                      const SizedBox(
                        height: 10,
                      ),
                      const Divider(
                        thickness: 1,
                        color: Colors.grey,
                      ),
                      Padding(
                        padding: const EdgeInsets.all(10.0),
                        child: InkWell(
                          onTap: () {
                            setState(() {
                              _timeType.text = "Full-time and Remotly Work";
                            });

                            Navigator.pop(context);
                          },
                          child: const Row(
                            mainAxisAlignment: MainAxisAlignment.start,
                            children: [
                              Icon(
                                Icons.arrow_right_alt_outlined,
                                color: Colors.white,
                              ),
                              SizedBox(
                                width: 6,
                              ),
                              Text(
                                "Full-time and Remotly Work",
                                style: TextStyle(color: Colors.white),
                              )
                            ],
                          ),
                        ),
                      ),
                    ],
                  )
                ],
              ),
            ),
            actions: [
              TextButton(
                  onPressed: () {
                    Navigator.canPop(context) ? Navigator.pop(context) : Null;
                  },
                  child: const Text(
                    "Cancel",
                    style: TextStyle(color: Colors.green, fontSize: 16),
                  )),
            ],
          );
        });
  }

  void _selectStatus({required Size size}) {
    showDialog(
        context: context,
        builder: (context) {
          return AlertDialog(
            backgroundColor: Colors.black54,
            title: const Text(
              "Select Status",
              textAlign: TextAlign.center,
              style: TextStyle(fontSize: 20, color: Colors.green),
            ),
            content: SizedBox(
              width: size.width * 0.9,
              child: ListView(
                shrinkWrap: true,
                children: [
                  Column(
                    mainAxisAlignment: MainAxisAlignment.start,
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      Padding(
                        padding: const EdgeInsets.all(10.0),
                        child: InkWell(
                          onTap: () {
                            setState(() {
                              _status.text = "true";
                            });

                            Navigator.pop(context);
                          },
                          child: const Row(
                            mainAxisAlignment: MainAxisAlignment.start,
                            children: [
                              Icon(
                                Icons.toggle_on,
                                color: Colors.white,
                              ),
                              SizedBox(
                                width: 6,
                              ),
                              Text(
                                "true",
                                style: TextStyle(color: Colors.white),
                              )
                            ],
                          ),
                        ),
                      ),
                      const SizedBox(
                        height: 10,
                      ),
                      const Divider(
                        thickness: 1,
                        color: Colors.grey,
                      ),
                      Padding(
                        padding: const EdgeInsets.all(10.0),
                        child: InkWell(
                          onTap: () {
                            setState(() {
                              _status.text = "false";
                            });
                            Navigator.pop(context);
                          },
                          child: const Row(
                            mainAxisAlignment: MainAxisAlignment.start,
                            children: [
                              Icon(
                                Icons.toggle_off,
                                color: Colors.white,
                              ),
                              SizedBox(
                                width: 6,
                              ),
                              Text(
                                "false",
                                style: TextStyle(color: Colors.white),
                              )
                            ],
                          ),
                        ),
                      ),
                    ],
                  )
                ],
              ),
            ),
            actions: [
              TextButton(
                  onPressed: () {
                    Navigator.canPop(context) ? Navigator.pop(context) : Null;
                  },
                  child: const Text(
                    "Cancel",
                    style: TextStyle(color: Colors.green, fontSize: 16),
                  )),
            ],
          );
        });
  }
}
